@@ -3,9 +3,33 @@ import warnings
 
 from unittest.mock import patch
 
+import pytest
+
 from faker import Faker
 
 
+@pytest.mark.parametrize(
+    'mock_random_number_source, right_digits, expected_decimal_part',
+    (
+        ('1234567', 5, '12345'),
+        ('1234567', 0, '1'),  # This is kinda interesting - same as 1 digit
+        ('1234567', 1, '1'),
+        ('1234567', 2, '12'),
+        ('0123', 1, '1'),
+    ),
+)
+def test_pyfloat_right_and_left_digits_positive(mock_random_number_source, right_digits, expected_decimal_part):
+
+    # Remove the randomness from the test by mocking the `BaseProvider.random_number` value
+    def mock_random_number(self, digits=None, fix_len=False):
+        return int(mock_random_number_source[:digits or 1])
+
+    with patch('faker.providers.BaseProvider.random_number', mock_random_number):
+        result = Faker().pyfloat(left_digits=1, right_digits=right_digits, positive=True)
+        decimal_part = str(result).split('.')[1]
+        assert decimal_part == expected_decimal_part
+
+
 class TestPyint(unittest.TestCase):
     def setUp(self):
         self.fake = Faker()
@@ -63,7 +87,7 @@ class TestPyfloat(unittest.TestCase):
     def test_positive(self):
         result = self.fake.pyfloat(positive=True)
 
-        self.assertGreaterEqual(result, 0)
+        self.assertGreater(result, 0)
         self.assertEqual(result, abs(result))
 
     def test_min_value(self):
@@ -99,7 +123,7 @@ class TestPyfloat(unittest.TestCase):
 
         result = self.fake.pyfloat(positive=True, max_value=100)
         self.assertLessEqual(result, 100)
-        self.assertGreaterEqual(result, 0)
+        self.assertGreater(result, 0)
 
     def test_positive_and_min_value_incompatible(self):
         """
@@ -108,7 +132,7 @@ class TestPyfloat(unittest.TestCase):
         """
 
         expected_message = (
-            "Cannot combine positive=True and negative min_value"
+            "Cannot combine positive=True with negative or zero min_value"
         )
         with self.assertRaises(ValueError) as raises:
             self.fake.pyfloat(min_value=-100, positive=True)
@@ -116,6 +140,14 @@ class TestPyfloat(unittest.TestCase):
         message = str(raises.exception)
         self.assertEqual(message, expected_message)
 
+    def test_positive_doesnt_return_zero(self):
+        """
+        Choose the right_digits and max_value so it's guaranteed to return zero,
+        then watch as it doesn't because positive=True
+        """
+        result = self.fake.pyfloat(positive=True, right_digits=0, max_value=1)
+        self.assertGreater(result, 0)
+
 
 class TestPystrFormat(unittest.TestCase):
 
